struct MatchCollector {
matches_by_node: FxHashMap<SyntaxNode, Match>,
}Fields
matches_by_node: FxHashMap<SyntaxNode, Match>Implementations
Sourceimpl MatchCollector
impl MatchCollector
Sourcefn add_match(&mut self, m: Match, sema: &Semantics<'_, RootDatabase>)
fn add_match(&mut self, m: Match, sema: &Semantics<'_, RootDatabase>)
Attempts to add m to matches. If it conflicts with an existing match, it is discarded. If
it is entirely within the a placeholder of an existing match, then it is added as a child
match of the existing match.